@@ -50,7 +50,7 @@ INSTRUCTIONS:
 {instructions}
 
 Your code must obey the following constraints:
-- In xpaths, to get the text of an element, do NOT use `text()`. Use `normalize-space()` instead. The xpath for an element whose text is "text" is "//*[normalize-space() = 'text']". The xpath for an element that contains text is "//*[contains(normalize-space(), 'text')]".
+- In xpaths, to get the text of an element, do NOT use `text()` (use `normalize-space()` instead), and don't use "normalize-space() = 'text'", use "contains(normalize-space(), 'text')" instead. For instance, the xpath for a button element that contains text is "//button[contains(normalize-space(), 'text')]".
 - Do NOT use `element.text` to get text. Use `env.get_text_of_element(element)` instead.
 - Do NOT use `element.send_keys(text)` or `element.click()`. Use `env.send_keys(text)` and `env.click(element)` instead.
 - Only do what I instruct you to do.
