@@ -21,7 +21,7 @@ from langchain.chat_models import ChatOpenAI
 from .compilers.instruction_compiler import InstructionCompiler
 from .memories import Memory
 
-TIME_BETWEEN_ACTIONS = 0.1
+TIME_BETWEEN_ACTIONS = 0.01
 
 import logging
 
@@ -552,6 +552,10 @@ class GPTSeleniumAgent:
     def send_keys(self, element: GPTWebElement, keys):
         element.send_keys(keys)
 
+    @__switch_to_element_iframe
+    def get_text_of_element(self, element):
+        return element.text
+
     @__switch_to_element_iframe
     def click(self, element: GPTWebElement):
         wait_time = TIME_BETWEEN_ACTIONS
